@@ -116,7 +116,7 @@ def _validated_mapped_value(mapper, key):
 def structure_to_schema(structure, definitions_schema, serialization_mapper=None):
     """
     Generate JSON schema from :class:`Structure`
-    `See working examples in test. <https://github.com/loyada/typedpy/tree/master/tests/schema_mapping>`_
+    `See working examples in tests. <https://github.com/loyada/typedpy/tree/master/tests/schema_mapping>`_
 
     Arguments:
         structure( subclass of :class:`Structure` ):
@@ -272,6 +272,10 @@ def schema_to_struct_code(
         definitions_schema(dict):
             schema for definitions of objects that can be referred to in the main schema. If non exist,
             just use an empty dict.
+        additional_fields(list):
+            additional Types of Fields with custom schema mapping that can appear in the schema. These
+            have to implement the class method from_json_schema(), which should return a string of the code
+            the Schema is mapping to.
     Returns:
         A string with the code of the class. This can either be executed directly,
         using exec(), or written to a file.
@@ -348,7 +352,7 @@ def write_code_from_schema(
 
     .. code-block:: python
 
-        write_code_from_schema(schema, definitions, "generated_sample.py", "Poo")
+        write_code_from_schema(schema, definitions, "generated_sample.py", "Poo", additional_fields=[CustomField1, CustomField2])
 
 
     Arguments:
@@ -361,7 +365,8 @@ def write_code_from_schema(
             the file name for the output. Typically should be end with ".py".
         class_name(str):
             the main Structure name
-        additional_fields(list[Type[Field]]) - additional field classes with custom mapping
+        additional_fields(list[Type[Field]]):
+            additional field classes with custom mapping
     """
     supporting_classes = schema_definitions_to_code(
         definitions_schema, additional_fields=additional_fields
